Object Oriented Tutorials
=========================

.. currentmodule:: H2MM_C

This section details how to analyze data in an object oriented approach.
This means calling methods instead of functions.
The code is often cleaner looking, but it can also be easier to make mistakes compared to the functional approach.

.. seealso::

    All tutorials in this section are replicated using the equivalent function calls in the :doc:`Function Oriented Tutorials <FFTutorial>` section.

.. toctree::
    :Caption: Tutorials
    :maxdepth: 2

    OOptimizationTutorial
    OBoundingTutorial

